GOOF----LE-4-2.0      ] C 4   hc      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  receive	 		g  filenameS	
f  ice-9/receive.scm	g  exportsS	 	
g  set-current-module	
 	
 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any				g  
syntax-object	g  call-with-values	g  top	 	g  ribcage	 g  dummy	!g  vars	"g  vals	#g  body	$ !"# 	%g  m-U5fywHbu8vS1u8SOAUMtR9-3442	&% 	'& 	(f  l-U5fywHbu8vS1u8SOAUMtR9-3447	)f  l-U5fywHbu8vS1u8SOAUMtR9-3448	*f  l-U5fywHbu8vS1u8SOAUMtR9-3449	+f  l-U5fywHbu8vS1u8SOAUMtR9-3450	,()*+ 	-$', 	. 	/g  x	0/ 	1& 	2f  l-U5fywHbu8vS1u8SOAUMtR9-3444	32 	4013 	5-.4 	6g  hygiene	76 	857 	9g  lambda	:957 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  cond-expand-provide	@g  current-module	Ag  srfi-8	BA C 5h  o   ]4	
5 4 >  "  G   48:    h   c   ]  C[       g  dummy
		 g  vars		 g  vals			 g  body			  			   C=>      h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/receive.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  varsg  valsg  body  C5R?i4@i5 B6 g       g  m
		(  g  filenamef  ice-9/receive.scm		
				&	
 	
   C6 